@@ -1,6 +1,6 @@
 #' Returns a SQL query with formula to calculate fitted values
 #'
-#' @param model An R model or a tibble with a parsed model
+#' @param model An R model or a list with a parsed model
 #' @param con Database connection object. It is used to select
 #' the correct SQL translation syntax.
 #'
@@ -14,7 +14,12 @@
 #' @export
 tidypredict_sql <- function(model, con) {
   f <- tidypredict_fit(model)
-  dbplyr::translate_sql(!! f, con = con)
+  if(class(f) == "call") {
+    dbplyr::translate_sql(!! f, con = con)
+  } else {
+    map(f, ~ dbplyr::translate_sql(!! .x, con = con))
+  }
+    
 }
 
 #' Returns a SQL query with formula to calculate predicted interval
@@ -24,7 +29,7 @@ tidypredict_sql <- function(model, con) {
 #' @param con  Database connection object. It is used to select
 #' the correct SQL translation syntax.
 #' @param interval The prediction interval, defaults to 0.95
-#'
+#' 
 #' @examples
 #' library(dbplyr)
 #'
@@ -35,5 +40,9 @@ tidypredict_sql <- function(model, con) {
 #' @export
 tidypredict_sql_interval <- function(model, con, interval = 0.95) {
   f <- tidypredict_interval(model, interval)
-  dbplyr::translate_sql(!! f, con = con)
+  if(class(f) == "call") {
+    dbplyr::translate_sql(!! f, con = con)
+  } else {
+    map(f, ~ dbplyr::translate_sql(!! .x, con = con))
+  }
 }
